==> bluefish_0.3.5.orig.tar.gz: bluefish-0.3.5/src/init.h <==
/* Bluefish HTML Editor
 * init.h --> all configurational options
 *
 * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
 * font selection code Copyright (C) 1999 MJ Ray
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __INIT_H_
#define __INIT_H_

#include <glib.h>
#include <gtk/gtkwidget.h>

/*
 * these values represent the options if the users wants to see the:
 * v_html_tb: html toolbar
 * v_custom_tb: custom menubar
 * v_main_tb: main toolbar
 */
extern gint v_html_tb, v_custom_tb, v_main_tb;

/*The initial window sizes: */
extern gint main_window_h, main_window_w;

/*
 * these values represent the command options for invoking the 
 * external programs used
 */
extern gchar *cfg_browser_cline;
extern gchar *cfg_weblint_cline;

/* assume netscape is on the path */
#define DEFAULT_BROWSER "netscape -remote OpenUrl\\(%s\\)"
#define DEFAULT_WEBLINT "weblint"
#define COMMAND_MAX 1024


/* fonts to use in the editor and the tab_width */
extern gchar *cfg_editor_font;
extern gint cfg_editor_tabwidth;


/* the position of the tabs of the notebook, can be "bottom", "top", "left" and "right" 
 * font to use
 */
extern gchar *cfg_tab_pos, *cfg_tab_font;

/*
 * This is the string added to the thumbnailfilename
 * and the default thumbnail type, can be "jpg", "png" or "gif"
 */
extern gchar *cfg_thumbnailstring;
extern gchar *cfg_thumbnailtype;


/* do we insert the closing tag for LI and P ? */
extern gint full_p, full_li;

/* do we insert lowercase HTML tags ? */
extern gint lowercase_tags;

/*
 * These values are pointers to the lists that are used in multiple 
 * combo widgets
 */
extern GList *positionlist;

/*
 * these are the functions in init.c that are used to parse config files
 */

gint chk_dir (gchar * name);
gint chk_link (gchar * src_name, gchar * dst_name);
gint chk_file (gchar * name, gchar * content);
gint check_directories ();
GList *make_config_list_item (GList * config_list, void *pointer_to_var, unsigned char type_of_var, gchar * name_of_var);
gint save_config_file (GList * config_list, gchar * filename);
gint parse_config_file (GList * config_list, gchar * filename);
void parse_config_files ();
void save_config_files ();
gint rcfile_init ();

#endif	/* __INIT_H_ */

==> bluefish-0.3.6.tar.gz: bluefish-0.3.6/src/init.h <==
/* Bluefish HTML Editor
 * init.h --> all configurational options
 *
 * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
 * font selection code Copyright (C) 1999 MJ Ray
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __INIT_H_
#define __INIT_H_

#include <glib.h>
#include <gtk/gtkwidget.h>

/* assume netscape is on the path */
#define DEFAULT_BROWSER "netscape -remote OpenUrl\\(%s\\)"
#define DEFAULT_WEBLINT "weblint"
#define COMMAND_MAX 1024

typedef struct {
	gchar *command;
	GtkItemFactoryEntry entry;
} Texternal_menu;

/*
 * These values are pointers to the lists that are used in multiple 
 * combo widgets
 */
extern GList *positionlist;

/*
 * these are the functions in init.c that are used to parse config files
 */

gint chk_dir(gchar * name);
gint chk_link(gchar * src_name, gchar * dst_name);
gint chk_file(gchar * name, gchar * content);
gint check_directories();
GList *make_config_list_item(GList * config_list, void *pointer_to_var, unsigned char type_of_var, gchar * name_of_var);
gint save_config_file(GList * config_list, gchar * filename);
gint parse_config_file(GList * config_list, gchar * filename);
void parse_config_files();
void save_config_files();
void make_external_menu_entries(gint which_external);
gint rcfile_init();

#endif							/* __INIT_H_ */
